module Fbp
=begin
=== Description
The Aggregator node puts itself into a transaction which will cause all of
the incoming IPs to be aggregated until the upstream node has completed then
the aggregated IPs will be sent on to the down stream node(s)
=end
  class Aggregator_node < Node
=begin rdoc
When a Aggregator_node is created, it is immediately put into a transaction.
This allows the  Aggregator_node to aggregate all of the IPs that come to it
until the up stream node completes its work
=end
    def initialize()
      super()
      write_to_input({:begin_transaction => true})
    end

=begin rdoc
Once the up stream node completes.  The transaction will end and
all of the IPs that had been accumulated during the transaction will
be sent to the down stream node.
=end
    def do_node_work(args)
      args.delete :completed
      write_to_output(args)
      false
    end

  end
end