module Fbp
=begin rdoc
== Description
The Assign_node will take its incoming IPs and add items to the hash
before passing it one to its down stream node(s)

== Discussion
The Assign_node takes an optional IIP of the form <tt>{:additional_args =>{}}</tt>

The hash contains the items that will be added to every incoming
IP sent to this node. The IIP is optional with this node.  If no
additional arguments are given to this node then it will simply write all
of its in coming IPs to its output.
=end
	class Assign_node < Node

=begin rdoc
When creating a new Assign_node instance one can optionally provide a hash
containing the items to be added to every in coming IP
=end
		def initialize(additional_args = nil)
			super()
			@options[:additional_args] = additional_args if !additional_args.nil?
		end

=begin rdoc
If an IIP has set the :additional_args key in options, then those items
will be appended to every incoming IP.  If the :additional_args key has
not been set then the IP will be passed downstream untouched.

If the IP has an :ips key then each of those IP in the array of IPs
will be modified as described above.
=end
		def  do_node_work(args)
			ips =  args.has_key? :ips ? args[:ips] : [args]
			ips.each {|ip| ip.merge!(@options[:additional_args]) if @options.has_key? :additional_args}
			super(args)
		end

	end
end