module Fbp
=begin
=== Description
The counter node counts either incoming IPs or IPs that
contain a certain key and then adds that count data to
the incoming IPs
=end
	class Counter_node < Node

=begin rdoc
When creating a new Counter_node instance one can optionally provide a
symbol which would be used to match a key in an incoming IP.  The IP
would then only be counted if the IP contained that key.
=end
		def initialize(key = nil)
			super()
			@options[:key] = key if !key.nil?
		end

=begin rdoc
When an IP is received if a key has been set then the IP will be
checked to see if it contains that key.  If so then it is counted.

If the incoming IP has the :ips key then the nested IPs will be
search for the matching key and counted if found.

In either a single IP or an IP with the :ips key is received and
no key has been set, then all IPs will be counted.
=end
		def do_node_work(args)
			counter = 0
			ips =  args.has_key? :ips ? args[:ips] : [args]

			key = nil
			key = @options[:key] if @options.has_key?(:key)

			ips.each do |ip|
				if key.nil?
					counter += 1
				else
					counter += 1 if ip.has_key?(key)
				end
			end

			args[:counter] = counter
			super(args)
		end

	end
end