require "thread-pool/thread-pool.rb"

module Fbp

=begin rdoc
=== Description
The Node pool class is built upon Kim Burgestrand Pool class which provides thread pool management
for Ruby.  The Node pool provides a standard set of module functions that allow for setting the
number of threads in the Pool and to shutdown the Pool.
=end
	class Node_pool #:nodoc:

		attr_reader :pool  #:nodoc:
		attr_reader :num_threads  #:nodoc:

		def initialize (num_threads = 10) #:nodoc:
			@num_threads = num_threads
			@pool = nil
		end

		def make_pool   #:nodoc:
		  return false if !@pool.nil?
			@pool = Pool.new(@num_threads)
		end

		def num_threads=(num_threads) #:nodoc:
			@num_threads = num_threads if @pool.nil?
		end

		def shutdown   #:nodoc:
			@pool.shutdown if !@pool.nil?
			@pool = nil
		end

	end
	
	@@node_pool = Node_pool.new  #:nodoc:

=begin rdoc
The  num_threads= sets the number of threads that will be used by the thread pool
that will be used for any Fbp network.  The default value is 10 threads.  This
function <b>only</b> works <b>before></b>  calling Fbp::make_pool.  After that this
function will do nothing
=== Parameters
+num_threads+ - The number of threads that should be used in the Thread Pool
=end
  public
	def self.num_threads= (num_threads)
		@@node_pool.num_threads = num_threads
	end

=begin
Returns that number of threads that are in the Pool
=end
  public
	def self.num_threads
		@@node_pool.num_threads
	end

=begin
This function will create the thread pool that will be used by any Fbp network.
This function <b>must</b> be called before executing any Fbp network.
=end
  public
	def self.make_pool
		@@node_pool.make_pool
	end

=begin
This function will return back if Fbp::make_pool has been called and a Pool has
been created.
=end
  public
	def self.has_pool
		!@@node_pool.pool.nil?
	end

=begin
This function will stop all running threads in the Fbp pool.  Calling this function
will kill all Fbp processing.
=end
  public
	def self.shutdown
		!@@node_pool.shutdown
  end

  protected
  def self.schedule(&block)  #:nodoc:
    @@node_pool.pool.schedule { block.call } if !@@node_pool.pool.nil?
  end
end