module Fbp
=begin
=== Description
The Text file reader node takes in a file path as an IIP and will open that
file and read a line at a time and package that data as an IP and send that
data to the downstream node.

=== Discussion
The Test_file_reader_node requires the file to be read exists before running this
node.
=end
	class Test_file_reader_node < Node
=begin rdoc
When creating a new Test_file_reader_node instance one can provide
a string which is the full path to the file to be read.
=end
		def initialize(file_name = nil)
			super()
      @options[:requires_input] = false
			@options[:file_name] = file_name if !file_name.nil?
			@file = nil
		end

=begin rdoc
Checks to see if this Test_file_reader_node instance has
a file_name set.  If so then true will be returned otherwise
false.
=end
	  def is_ready_to_run?()
			@options.has_key? :file_name
		end

=begin
Once this instance is executed, it will open the file
specified in the  :file_name option and read a line
at a time.  A line is defined as a series of characters
up to a return character.

Once a line is read, an IP is made with that data
keys with :data and sent to the down stream node.

When the EOF is reached the file will be closed.
=end
		def do_node_work(args)

      if args.has_key? :completed
        @file.close  if !@file.nil?
        @file = nil
        return false
      end

      if args.has_key? :continue

        file_line = nil
        close_file = false
        @file = File.new(@options[:file_name], 'r') if @file.nil?


			  begin
				  file_line = @file.gets
          close_file = true if file_line.nil?
          close_file = true if @file.eof?
			  rescue
				  close_file = true
			  end

			  write_to_output({:data => file_line}) if !file_line.nil?

			  if close_file
				  @file.close
				  @file = nil
          return false
        end
      end
			
			true
		end

	end
end