module Fbp
=begin
=== Description
The Text file writer node takes in a file path as an IIP and will open that
file and will take in IPs and write the value of the :data item in the IP to
the file.

== Discussion
The Text_file_writer_node does allow for setting the file open mode by having
an IIP with a :file_open_mode key specifying the open mode.  Setting this value
using an IIP allows for setting the open mode to a+ so appending instead of the
the default which to overwrite the file using "w"
=end
	class Text_file_writer_node < Node
=begin rdoc
When creating a new Text_file_writer_node instance one can provide
a string which is the full path to the file to be written.
=end
		def initialize(file_name = nil)
			super()
			@options[:file_name] = file_name if !file_name.nil?
			@options[:file_open_mode] = 'w'
			@file = nil
		end
=begin rdoc
Checks to see if this Text_file_writer_node instance has
a file_name and file_open_mode set.  If so then true will be
returned otherwise false.
=end
		def is_ready_to_run?()
			@options.has_key?(:file_name) && @options.has_key?(:file_open_mode)
		end
=begin rdoc
When an IP is received the IP is checked to see if it has a :data key.
If it does then that data is written to the file specified by the
:file_name option.  This will continue until an IP is sent with the
:completed  key at which will cause the file to be closed.
=end
		def do_node_work(args)

      if args.has_key? :completed
        @file.close if !@file.nil?
        @file = nil
        return false
      end

      if args.has_key? :data
        data = args[:data]

        if data.nil?
          @file.close if !@file.nil?
          @file = nil
          return false
        end

        @file = File.new(@options[:file_name], @options[:file_open_mode]) if @file.nil?
        @file.write(data)
        @file.flush
      end

			true
		end

	end
end